@@ -1,5 +1,5 @@
 /* mechinfo.c --- Definition of GS2 mechanism.
- * Copyright (C) 2006 Simon Josefsson
+ * Copyright (C) 2006, 2010 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -47,17 +47,8 @@ Gsasl_mechanism gsasl_gs2_krb5_mechanism = {
 #else
    NULL,
 #endif
-#ifdef USE_CLIENT
-   _gsasl_gs2_client_encode,
-#else
    NULL,
-#endif
-#ifdef USE_CLIENT
-   _gsasl_gs2_client_decode
-#else
-   NULL
-#endif
-   }
+   NULL}
   ,
   {
    NULL,
