@@ -1,5 +1,5 @@
 /* digest-md5.c --- Test the DIGEST-MD5 mechanism.
- * Copyright (C) 2002, 2003, 2004, 2007, 2008, 2009  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2007, 2008, 2009, 2010  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -192,13 +192,15 @@ doit (void)
       res = gsasl_server_start (ctx, "DIGEST-MD5", &server);
       if (res != GSASL_OK)
 	{
-	  fail ("gsasl_init() failed (%d):\n%s\n", res, gsasl_strerror (res));
+	  fail ("gsasl_server_start() failed (%d):\n%s\n",
+		res, gsasl_strerror (res));
 	  return;
 	}
       res = gsasl_client_start (ctx, "DIGEST-MD5", &client);
       if (res != GSASL_OK)
 	{
-	  fail ("gsasl_init() failed (%d):\n%s\n", res, gsasl_strerror (res));
+	  fail ("gsasl_client_start() failed (%d):\n%s\n",
+		res, gsasl_strerror (res));
 	  return;
 	}
 
@@ -213,7 +215,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%c]\n", (int) s1len,
+		s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Server starts... */
 
@@ -227,7 +230,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s [%c]\n", s2len, s2, res == GSASL_OK ? 'O' : 'N');
+	printf ("S: %.*s [%c]\n", (int) s2len,
+		s2, res == GSASL_OK ? 'O' : 'N');
 
       /* Client responds... */
 
@@ -241,7 +245,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%c]\n", (int) s1len,
+		s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Server finishes... */
 
@@ -255,7 +260,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s [%c]\n", s2len, s2, res == GSASL_OK ? 'O' : 'N');
+	printf ("S: %.*s [%c]\n", (int) s2len,
+		s2, res == GSASL_OK ? 'O' : 'N');
 
       /* Client finishes. */
 
@@ -270,13 +276,15 @@ doit (void)
 
       if (s1len != 0)
 	{
-	  fail ("gsasl_step() failed, additional length=%d:\n", s1len);
+	  fail ("gsasl_step() failed, additional length=%lu:\n",
+		(unsigned long) s1len);
 	  fail ("%s\n", s1);
 	  return;
 	}
 
       if (debug)
-	printf ("C: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%c]\n", (int) s1len,
+		s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Server is done. */
 
@@ -333,7 +341,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("S: %.*s [%c]\n", (int) s1len,
+		s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Client respond... */
 
@@ -347,7 +356,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s [%c]\n", s2len, s2, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%c]\n", (int) s2len,
+		s2, res == GSASL_OK ? 'O' : 'N');
 
       /* Server finishes... */
 
@@ -361,7 +371,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("S: %.*s [%c]\n", (int) s1len,
+		s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Client finishes... */
 
@@ -375,7 +386,8 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s [%c]\n", s2len, s2, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%c]\n", (int) s2len,
+		s2, res == GSASL_OK ? 'O' : 'N');
 
       /* Server is done. */
 
@@ -412,7 +424,7 @@ doit (void)
       if (debug)
 	{
 	  if (s1len == 3 && memcmp (s1, "foo", 3) == 0)
-	    printf ("C: %.*s\n", s1len, s1);
+	    printf ("C: %.*s\n", (int) s1len, s1);
 	  else
 	    {
 	      char *out;
@@ -426,7 +438,7 @@ doit (void)
 		  return;
 		}
 
-	      printf ("C: %.*s\n", outlen, out);
+	      printf ("C: %.*s\n", (int) outlen, out);
 	      free (out);
 	    }
 	}
@@ -443,7 +455,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s\n", s2len, s2);
+	printf ("S: %.*s\n", (int) s2len, s2);
 
       free (s2);
 
@@ -460,7 +472,7 @@ doit (void)
       if (debug)
 	{
 	  if (s1len == 3 && memcmp (s1, "bar", 3) == 0)
-	    printf ("S: %.*s\n", s1len, s1);
+	    printf ("S: %.*s\n", (int) s1len, s1);
 	  else
 	    {
 	      char *out;
@@ -474,7 +486,7 @@ doit (void)
 		  return;
 		}
 
-	      printf ("S: %.*s\n", outlen, out);
+	      printf ("S: %.*s\n", (int) outlen, out);
 	      free (out);
 	    }
 	}
@@ -491,7 +503,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s\n", s2len, s2);
+	printf ("C: %.*s\n", (int) s2len, s2);
 
       free (s2);
 
