@@ -1,5 +1,5 @@
 /* cram-md5.c --- Test the CRAM-MD5 mechanism, using old callback API.
- * Copyright (C) 2002, 2003, 2004, 2005, 2007, 2009  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2007, 2009, 2010  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -120,13 +120,15 @@ doit (void)
       res = gsasl_server_start (ctx, "CRAM-MD5", &server);
       if (res != GSASL_OK)
 	{
-	  fail ("gsasl_init() failed (%d):\n%s\n", res, gsasl_strerror (res));
+	  fail ("gsasl_server_start() failed (%d):\n%s\n",
+		res, gsasl_strerror (res));
 	  return;
 	}
       res = gsasl_client_start (ctx, "CRAM-MD5", &client);
       if (res != GSASL_OK)
 	{
-	  fail ("gsasl_init() failed (%d):\n%s\n", res, gsasl_strerror (res));
+	  fail ("gsasl_client_start() failed (%d):\n%s\n",
+		res, gsasl_strerror (res));
 	  return;
 	}
 
@@ -138,7 +140,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s\n", s1len, s1);
+	printf ("S: %.*s\n", (int) s1len, s1);
 
       res = gsasl_step (client, s1, s1len, &s2, &s2len);
       free (s1);
@@ -149,7 +151,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s\n", s2len, s2);
+	printf ("C: %.*s\n", (int) s2len, s2);
 
       res = gsasl_step (server, s2, s2len, &s1, &s1len);
       free (s2);
@@ -161,7 +163,8 @@ doit (void)
 
       if (s1len != 0)
 	{
-	  fail ("gsasl_step() failed, additional length=%d:\n", s1len);
+	  fail ("gsasl_step() failed, additional length=%lu:\n",
+		(unsigned long) s1len);
 	  fail ("%s\n", s1);
 	  return;
 	}
