@@ -157,13 +157,15 @@ doit (void)
       res = gsasl_server_start (ctx, "DIGEST-MD5", &server);
       if (res != GSASL_OK)
 	{
-	  fail ("gsasl_init() failed (%d):\n%s\n", res, gsasl_strerror (res));
+	  fail ("gsasl_server_start() failed (%d):\n%s\n",
+		res, gsasl_strerror (res));
 	  return;
 	}
       res = gsasl_client_start (ctx, "DIGEST-MD5", &client);
       if (res != GSASL_OK)
 	{
-	  fail ("gsasl_init() failed (%d):\n%s\n", res, gsasl_strerror (res));
+	  fail ("gsasl_client_start() failed (%d):\n%s\n",
+		res, gsasl_strerror (res));
 	  return;
 	}
 
@@ -180,7 +182,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s\n", s1len, s1);
+	printf ("S: %.*s\n", (int) s1len, s1);
 
       /* Client respond... */
 
@@ -194,7 +196,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s\n", s2len, s2);
+	printf ("C: %.*s\n", (int) s2len, s2);
 
       /* Server finishes... */
 
@@ -208,7 +210,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s\n", s1len, s1);
+	printf ("S: %.*s\n", (int) s1len, s1);
 
       /* Client finishes... */
 
@@ -226,7 +228,7 @@ doit (void)
 	  /* Solaris x86 crashes here if s2 is NULL, even when s2len
 	     is 0. */
 	  if (s2len)
-	    printf ("C: %.*s\n", s2len, s2);
+	    printf ("C: %.*s\n", (int) s2len, s2);
 	  else
 	    printf ("C: \n");
 	}
